/*
 * layout.c
 * 
 * Copyright (c) 2012 Hedgehog LLC, www.hedghog.ee/ipho
 * 
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files 
 * (the "Software"), to deal in the Software without restriction, 
 * including without limitation the rights to use, copy, modify, merge, 
 * publish, distribute, sublicense, and/or sell copies of the Software, 
 * and to permit persons to whom the Software is furnished to do so, 
 * subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be 
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY 
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE 
 * SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 * 
 */


#include "layout.h"
#include <avr/interrupt.h>
#include <util/delay.h>

uint8_t  EEMEM Splash[LCD_LINES][LCD_LINE_LENGTH] = {"-=[ IPhO-measure ]=-",
                                                     "Info, schematics and",
                                                     "  source code at:   ",
                                                     "www.hedgehog.ee/ipho"};
uint16_t EEMEM bootloader_version = 126;//BOOTLOADER_REVISION_TAG
uint16_t EEMEM serial_number = 0;
uint8_t EEMEM stay_in_bootloader = 1;

					//[channel][attenuator on/off][range][offset/linear]
int16_t EEMEM v_calibration[7][2][6][2] = {{{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}},
					{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}}},
					{{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}},
					{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}}},
					{{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}},
					{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}}},
					{{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}},
					{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}}},
					{{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}},
					{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}}},
					{{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}},
					{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}}},
					{{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}},
					{{16384,0},{16384,0},{16384,0},{16384,0},{16384,0},{16384,0}}}};

float EEMEM i_resistor_calibration = 0.820;      //current sense resistor value

int16_t EEMEM test_calibration[N_TEST_POINTS];
int16_t EEMEM test_end_voltage;

//set initial IO ddr, port and pin values
void initIO(void){
	DDRB = (_BV(ATTN_BIT)|_BV(SPI_MISO_PIN)|_BV(SPI_MOSI_PIN)|_BV(SPI_SCK_PIN)|_BV(SPI_SS_PIN));
	PORTB = (_BV(SPI_SS_PIN)|_BV(TOUCH_INT_BIT));

	DDRC = (_BV(POWER_SW_BIT)|_BV(LCD_RS_BIT)|_BV(LCD_RW_BIT)|_BV(LCD_E_BIT));
	PORTC = (_BV(POWER_SW_BIT)|_BV(POWER_SENSE_BIT));

	DDRD = 0xFF; //LCD data port
	PORTD = 0;
}

//turn of interfaces and jump to bootloader
void boot(void){
	cli();
	UDCON = 1;
	USBCON = (1<<FRZCLK);  // disable USB
	UCSR1B = 0;
	_delay_ms(5);
	EIMSK = 0;
	PCICR = 0;
	SPCR = 0;
	TIMSK0 = 0;
	TIMSK1 = 0;
	UCSR1B = 0;
	typedef void (*AppPtr_t)(void) __attribute__ ((noreturn));
	AppPtr_t AppStartPtr = (AppPtr_t)0x7000;
	AppStartPtr(); 
	//asm volatile("jmp 0x3800");	//BOOTLOADER_ADDR

}

//timer
uint32_t ovf_cnt = 0;

//overflow counter
ISR(TIMER1_OVF_vect){
	ovf_cnt++;
}

void timer_init(void){
	TIMSK1 = 0b1; //overflow interrupt
	TCCR1B = TIMER1_PRESCALER;
}

uint32_t time_now( void )
{
	unsigned int i;
	i = TCNT1;
	return (ovf_cnt<<16) | i;
}

void reset_timer(void){
	ovf_cnt = 0;
	TCNT1 = 0;
}

