#ifndef LAYOUT_H_
#define LAYOUT_H_
#include <avr/io.h>
#include <avr/eeprom.h>
#include "stdint.h"

//EEPROM
#define LCD_LINES			4	//visible lines
#define LCD_LINE_LENGTH		20	//line length (in characters)
extern uint8_t  EEMEM Splash[LCD_LINES][LCD_LINE_LENGTH];
extern uint16_t EEMEM bootloader_version;
extern uint16_t EEMEM serial_number;
extern uint8_t EEMEM stay_in_bootloader;
extern int16_t EEMEM v_calibration[7][2][6][2];	//[channel][attenuator on/off][range][offset/linear]
extern float EEMEM i_resistor_calibration;      //current sense resistor value
#define N_TEST_POINTS 43
extern int16_t EEMEM test_calibration[N_TEST_POINTS];
extern int16_t EEMEM test_end_voltage;

//PINOUT

//main power control
#define POWER_SENSE_PIN PINC
#define POWER_SENSE_BIT PINC6
#define POWER_SW_PORT PORTC
#define POWER_SW_BIT PORTC7

#define POWER_SW(on) (POWER_SW_PORT =(on ? POWER_SW_PORT|_BV(POWER_SW_BIT): POWER_SW_PORT & ~_BV(POWER_SW_BIT)))
#define POWER_SENSE() (POWER_SENSE_PIN &_BV(POWER_SENSE_BIT))

//adc input attenuator
#define ATTN_PORT PORTB
#define ATTN_BIT PINB7

#define ATTN_SW(on) (ATTN_PORT =(on ? ATTN_PORT|_BV(ATTN_BIT): ATTN_PORT & ~_BV(ATTN_BIT)))

//qtouch interrupt
#define TOUCH_INT_PIN PINB
#define TOUCH_INT_BIT PINB5
#define TOUCH_INT() ((TOUCH_INT_PIN & _BV(TOUCH_INT_BIT)) == 0)

//LCD control pins
#define LCD_RS_BIT	PORTC5 	//MCU pin connected to LCD RS
#define LCD_RW_BIT	PORTC4 	//MCU pin connected to LCD R/W
#define LCD_E_BIT	PORTC2		//MCU pin connected to LCD E

#define LCD_C_PORT	PORTC 	//MCU port connected to control pins
#define LCD_D_PORT	PORTD   //MCU port connected to data pins


//i2c pins
#define I2C_DDR DDRB
#define I2C_PIN PINB
#define I2C_SDA PINB6
#define I2C_SCL PINB4

//spi pins
#if (defined(__AVR_AT90USB82__) || defined(__AVR_AT90USB162__) || defined(__AVR_ATmega32U2__))
 #define SPI_SS_PIN PORTB0
 #define SPI_SCK_PIN PORTB1
 #define SPI_MOSI_PIN PORTB2
 #define SPI_MISO_PIN PORTB3
#elif (defined(__AVR_ATmega48__) || defined(_AVR_ATmega88__) || defined(__AVR_ATmega168__) || defined(__AVR_ATmega328__) || defined(__AVR_ATmega328P__))
 #define SPI_SS_PIN PORTB2
 #define SPI_SCK_PIN PORTB5
 #define SPI_MOSI_PIN PORTB3
 #define SPI_MISO_PIN PORTB4
#else
 #error unknown processor - add to spi.h
#endif

//set initial IO ddr, port and pin values
void initIO(void);

//turn of interfaces and jump to bootloader
#define BOOTLOADER_ADDR 0x3800
void boot(void);



#define TIMER_PRESCALER_1		1
#define TIMER_PRESCALER_8		2
#define TIMER_PRESCALER_64		3
#define TIMER_PRESCALER_256		4
#define TIMER_PRESCALER_1024	5


#define TIMER1_PRESCALER TIMER_PRESCALER_256
#define SECOND_TO_TIME			(F_CPU/256)


void timer_init(void);
uint32_t time_now(void);
void reset_timer(void);

#endif /* LAYOUT_H_ */
