//
// File Name	: 'lcd_lib.c'
// Title		: 8 and 4 bit LCd interface
// Author		: Scienceprog.com - Copyright (C) 2007
// Author		: Hedgehog LLC, www.hedgehog.ee/ipho - Copyright (C) 2012
// Created		: 2007-03-29
// Revised		: 2007-08-08
// Version		: 1.0
// Target MCU	: Atmel AVR series
//
// This code is distributed under the GNU Public License
//		which can be found at http://www.gnu.org/licenses/gpl.txt
//

#include <inttypes.h>
#include <avr/io.h>
#include <util/delay.h>
#include "lcd_lib.h"
#include "layout.h"

void LCDsendChar(uint8_t ch)		//Sends Char to LCD
{
	_delay_us(100);
	LCDsetData(ch);
	LCD_C_PORT|=1<<LCD_RS_BIT;
	LCD_C_PORT&=~(1<<LCD_RW_BIT);
	_delay_us(100);
	LCD_C_PORT|=1<<LCD_E_BIT;
	_delay_us(100);
	LCD_C_PORT&=~(1<<LCD_E_BIT);
}

void LCDsendCommand(uint8_t cmd)	//Sends Command to LCD
{
	_delay_us(100);
	LCDsetData(cmd);
	LCD_C_PORT&=~(1<<LCD_RW_BIT);
	LCD_C_PORT&=~(1<<LCD_RS_BIT);
	_delay_us(100);
	LCD_C_PORT|=1<<LCD_E_BIT;
	_delay_us(100);
	LCD_C_PORT&=~(1<<LCD_E_BIT);
}

void LCDinit(void)//Initializes LCD
{
	_delay_ms(45);
	LCDsetData(0x00);//LDP=0x00;
	LCD_C_PORT&=~(1<<LCD_E_BIT);
	//LCD_V0_P&=~(1<<LCD_V0_B);
	LCD_C_PORT&=~(1<<LCD_RW_BIT);
	LCD_C_PORT&=~(1<<LCD_RS_BIT);//LCP=0x00;
	LCD_C_PORT|=(1<<LCD_E_BIT);
	LCD_C_PORT|=(1<<LCD_RS_BIT);
	LCD_C_PORT|=(1<<LCD_RW_BIT);
	_delay_ms(20);
	LCDsendCommand(0b111000);
	_delay_ms(5);
	LCDsendCommand(0b111000);
	_delay_ms(1);
	LCDsendCommand(0b1100);
	_delay_ms(1);
	LCDsendCommand(0b1);
	_delay_ms(2);
	LCDsendCommand(0b110);	
		_delay_ms(2);
	LCDsendCommand(0b10100);
		_delay_ms(2);
}

void LCDclr(void)				//Clears LCD
{
	LCDsendCommand(1<<LCD_CLR);
}

void LCDhome(void)			//LCD cursor home
{
	LCDsendCommand(1<<LCD_HOME);
}

void LCDGotoY(/*uint8_t x,*/ uint8_t y)	//Cursor to X Y position
{
	/*register uint8_t DDRAMAddr;
	// remap lines into proper order
	switch(y)
	{
	case 0: DDRAMAddr = LCD_LINE0_DDRAMADDR+x; break;
	case 1: DDRAMAddr = LCD_LINE1_DDRAMADDR+x; break;
	case 2: DDRAMAddr = LCD_LINE2_DDRAMADDR+x; break;
	case 3: DDRAMAddr = LCD_LINE3_DDRAMADDR+x; break;
	default: DDRAMAddr = LCD_LINE0_DDRAMADDR+x;
	}
	// set data address
	LCDsendCommand(1<<LCD_DDRAM | DDRAMAddr);
	*/
	switch(y)
	{
		case 0: 	LCDsendCommand(1<<LCD_DDRAM | LCD_LINE0_DDRAMADDR); break;
		case 1: 	LCDsendCommand(1<<LCD_DDRAM | LCD_LINE1_DDRAMADDR); break;
		case 2: 	LCDsendCommand(1<<LCD_DDRAM | LCD_LINE2_DDRAMADDR); break;
		case 3: 	LCDsendCommand(1<<LCD_DDRAM | LCD_LINE3_DDRAMADDR); break;
	
	}
	
}
